import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { PopoverAnchor } from "@radix-ui/react-popover";
import { cn, withRef } from "@udecode/cn";
import { isSelectionExpanded } from "@udecode/plate-common";
import { PlateElement, useEditorRef, useEditorSelector, useElement, useRemoveNodeButton, withHOC, } from "@udecode/plate-common/react";
import { 
// @ts-ignore
mergeTableCells, TableProvider, 
// @ts-ignore
unmergeTableCells, useTableBordersDropdownMenuContentState, useTableElement, 
// @ts-ignore
useTableElementState, useTableMergeState, } from "@udecode/plate-table/react";
import { useReadOnly, useSelected } from "slate-react";
import { Icons, iconVariants } from "../icons";
import { Button } from "./button";
import { DropdownMenu, DropdownMenuCheckboxItem, DropdownMenuContent, DropdownMenuPortal, DropdownMenuTrigger, } from "./dropdown-menu";
import { Popover, PopoverContent, popoverVariants } from "./popover";
import { Separator } from "./separator";
export const TableBordersDropdownMenuContent = withRef((props, ref) => {
    const { getOnSelectTableBorder, hasBottomBorder, hasLeftBorder, hasNoBorders, hasOuterBorders, hasRightBorder, hasTopBorder, } = useTableBordersDropdownMenuContentState();
    return (_jsxs(DropdownMenuContent, { align: "start", className: cn("min-w-[220px]"), ref: ref, side: "right", sideOffset: 0, ...props, children: [_jsxs(DropdownMenuCheckboxItem, { checked: hasBottomBorder, onCheckedChange: getOnSelectTableBorder("bottom"), children: [_jsx(Icons.borderBottom, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "Bottom Border" })] }), _jsxs(DropdownMenuCheckboxItem, { checked: hasTopBorder, onCheckedChange: getOnSelectTableBorder("top"), children: [_jsx(Icons.borderTop, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "Top Border" })] }), _jsxs(DropdownMenuCheckboxItem, { checked: hasLeftBorder, onCheckedChange: getOnSelectTableBorder("left"), children: [_jsx(Icons.borderLeft, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "Left Border" })] }), _jsxs(DropdownMenuCheckboxItem, { checked: hasRightBorder, onCheckedChange: getOnSelectTableBorder("right"), children: [_jsx(Icons.borderRight, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "Right Border" })] }), _jsx(Separator, {}), _jsxs(DropdownMenuCheckboxItem, { checked: hasNoBorders, onCheckedChange: getOnSelectTableBorder("none"), children: [_jsx(Icons.borderNone, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "No Border" })] }), _jsxs(DropdownMenuCheckboxItem, { checked: hasOuterBorders, onCheckedChange: getOnSelectTableBorder("outer"), children: [_jsx(Icons.borderAll, { className: iconVariants({ size: "sm" }) }), _jsx("div", { children: "Outside Borders" })] })] }));
});
export const TableFloatingToolbar = withRef(({ children, ...props }, ref) => {
    const element = useElement();
    const { props: buttonProps } = useRemoveNodeButton({ element });
    const selectionCollapsed = useEditorSelector((editor) => !isSelectionExpanded(editor), []);
    const readOnly = useReadOnly();
    const selected = useSelected();
    const editor = useEditorRef();
    const collapsed = !readOnly && selected && selectionCollapsed;
    const open = !readOnly && selected;
    const { canMerge, canUnmerge } = useTableMergeState();
    const mergeContent = canMerge && (_jsxs(Button, { contentEditable: false, isMenu: true, onClick: () => mergeTableCells(editor), variant: "ghost", children: [_jsx(Icons.combine, { className: "mr-2 size-4" }), "Merge"] }));
    const unmergeButton = canUnmerge && (_jsxs(Button, { contentEditable: false, isMenu: true, onClick: () => unmergeTableCells(editor), variant: "ghost", children: [_jsx(Icons.ungroup, { className: "mr-2 size-4" }), "Unmerge"] }));
    const bordersContent = collapsed && (_jsxs(_Fragment, { children: [_jsxs(DropdownMenu, { modal: false, children: [_jsx(DropdownMenuTrigger, { asChild: true, children: _jsxs(Button, { isMenu: true, variant: "ghost", children: [_jsx(Icons.borderAll, { className: "mr-2 size-4" }), "Borders"] }) }), _jsx(DropdownMenuPortal, { children: _jsx(TableBordersDropdownMenuContent, {}) })] }), _jsxs(Button, { contentEditable: false, isMenu: true, variant: "ghost", ...buttonProps, children: [_jsx(Icons.delete, { className: "mr-2 size-4" }), "Delete"] })] }));
    return (_jsxs(Popover, { modal: false, open: open, children: [_jsx(PopoverAnchor, { asChild: true, children: children }), (canMerge || canUnmerge || collapsed) && (_jsxs(PopoverContent, { className: cn(popoverVariants(), "flex w-[220px] flex-col gap-1 p-1"), onOpenAutoFocus: (e) => e.preventDefault(), ref: ref, ...props, children: [unmergeButton, mergeContent, bordersContent] }))] }));
});
export const TableElement = withHOC(TableProvider, withRef(({ children, className, ...props }, ref) => {
    const { colSizes, isSelectingCell, marginLeft, minColumnWidth } = useTableElementState();
    const { colGroupProps, props: tableProps } = useTableElement();
    return (_jsx(TableFloatingToolbar, { children: _jsx("div", { style: { paddingLeft: marginLeft }, children: _jsx(PlateElement, { asChild: true, className: cn("my-4 ml-px mr-0 table h-px w-full table-fixed border-collapse", isSelectingCell && "[&_*::selection]:bg-none", className), ref: ref, ...tableProps, ...props, children: _jsxs("table", { children: [_jsx("colgroup", { ...colGroupProps, children: colSizes.map((width, index) => (_jsx("col", { style: {
                                    minWidth: minColumnWidth,
                                    width: width || undefined,
                                } }, index))) }), _jsx("tbody", { className: "min-w-full", children: children })] }) }) }) }));
}));
//# sourceMappingURL=table-element.js.map