import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { BlockquotePlugin } from "@udecode/plate-block-quote/react";
import { collapseSelection, getNodeEntries, isBlock, } from "@udecode/plate-common";
import { focusEditor, ParagraphPlugin, useEditorRef, useEditorSelector, } from "@udecode/plate-common/react";
import { HEADING_KEYS } from "@udecode/plate-heading";
import { Icons } from "../icons";
import { DropdownMenu, DropdownMenuContent, DropdownMenuLabel, DropdownMenuRadioGroup, DropdownMenuRadioItem, DropdownMenuTrigger, useOpenState, } from "./dropdown-menu";
import { ToolbarButton } from "./toolbar";
const items = [
    {
        description: "Paragraph",
        icon: Icons.paragraph,
        label: "Paragraph",
        value: ParagraphPlugin.key,
    },
    {
        description: "Heading 1",
        icon: Icons.h1,
        label: "Heading 1",
        value: HEADING_KEYS.h1,
    },
    {
        description: "Heading 2",
        icon: Icons.h2,
        label: "Heading 2",
        value: HEADING_KEYS.h2,
    },
    {
        description: "Heading 3",
        icon: Icons.h3,
        label: "Heading 3",
        value: HEADING_KEYS.h3,
    },
    {
        description: "Quote (⌘+⇧+.)",
        icon: Icons.blockquote,
        label: "Quote",
        value: BlockquotePlugin.key,
    },
    // {
    //   value: 'ul',
    //   label: 'Bulleted list',
    //   description: 'Bulleted list',
    //   icon: Icons.ul,
    // },
    // {
    //   value: 'ol',
    //   label: 'Numbered list',
    //   description: 'Numbered list',
    //   icon: Icons.ol,
    // },
];
const defaultItem = items.find((item) => item.value === ParagraphPlugin.key);
export function TurnIntoDropdownMenu(props) {
    const value = useEditorSelector((editor) => {
        let initialNodeType = ParagraphPlugin.key;
        let allNodesMatchInitialNodeType = false;
        const codeBlockEntries = getNodeEntries(editor, {
            match: (n) => isBlock(editor, n),
            mode: "highest",
        });
        const nodes = Array.from(codeBlockEntries);
        if (nodes.length > 0) {
            initialNodeType = nodes[0][0].type;
            allNodesMatchInitialNodeType = nodes.every(([node]) => {
                const type = node?.type || ParagraphPlugin.key;
                return type === initialNodeType;
            });
        }
        return allNodesMatchInitialNodeType ? initialNodeType : ParagraphPlugin.key;
    }, []);
    const editor = useEditorRef();
    const openState = useOpenState();
    const selectedItem = items.find((item) => item.value === value) ?? defaultItem;
    const { icon: SelectedItemIcon, label: selectedItemLabel } = selectedItem;
    return (_jsxs(DropdownMenu, { modal: false, ...openState, ...props, children: [_jsx(DropdownMenuTrigger, { asChild: true, children: _jsxs(ToolbarButton, { className: "lg:min-w-[130px]", isDropdown: true, pressed: openState.open, tooltip: "Turn into", children: [_jsx(SelectedItemIcon, { className: "size-5 lg:hidden" }), _jsx("span", { className: "max-lg:hidden", children: selectedItemLabel })] }) }), _jsxs(DropdownMenuContent, { align: "start", className: "min-w-0 bg-white", children: [_jsx(DropdownMenuLabel, { children: "Turn into" }), _jsx(DropdownMenuRadioGroup, { className: "flex flex-col gap-0.5", onValueChange: (type) => {
                            // if (type === 'ul' || type === 'ol') {
                            //   if (settingsStore.get.checkedId(IndentListPlugin.key)) {
                            //     toggleIndentList(editor, {
                            //       listStyleType: type === 'ul' ? 'disc' : 'decimal',
                            //     });
                            //   } else if (settingsStore.get.checkedId('list')) {
                            //     toggleList(editor, { type });
                            //   }
                            // } else {
                            //   unwrapList(editor);
                            editor.tf.toggle.block({ type });
                            // }
                            collapseSelection(editor);
                            focusEditor(editor);
                        }, value: value, children: items.map(({ icon: Icon, label, value: itemValue }) => (_jsxs(DropdownMenuRadioItem, { className: "min-w-[180px]", value: itemValue, children: [_jsx(Icon, { className: "mr-2 size-5" }), label] }, itemValue))) })] })] }));
}
//# sourceMappingURL=turn-into-dropdown-menu.js.map