"use client";
import { jsx as _jsx } from "react/jsx-runtime";
// PLUGINS
import { AlignPlugin } from "@udecode/plate-alignment/react";
import { AutoformatPlugin } from "@udecode/plate-autoformat/react";
import { BasicMarksPlugin, BoldPlugin, CodePlugin, ItalicPlugin, StrikethroughPlugin, SubscriptPlugin, SuperscriptPlugin, UnderlinePlugin, } from "@udecode/plate-basic-marks/react";
import { BlockquotePlugin } from "@udecode/plate-block-quote/react";
import { ExitBreakPlugin, SoftBreakPlugin } from "@udecode/plate-break/react";
import { CaptionPlugin } from "@udecode/plate-caption/react";
import { isCodeBlockEmpty, isSelectionAtCodeBlockStart, unwrapCodeBlock, } from "@udecode/plate-code-block";
import { CodeBlockPlugin, CodeLinePlugin, CodeSyntaxPlugin, } from "@udecode/plate-code-block/react";
import { CommentsPlugin } from "@udecode/plate-comments/react";
import { isBlockAboveEmpty, isSelectionAtBlockStart, someNode, } from "@udecode/plate-common";
import { createPlateEditor, ParagraphPlugin, PlateLeaf, } from "@udecode/plate-common/react";
import { EmojiPlugin } from "@udecode/plate-emoji/react";
import { ExcalidrawPlugin } from "@udecode/plate-excalidraw/react";
import { FontBackgroundColorPlugin, FontColorPlugin, FontSizePlugin, } from "@udecode/plate-font/react";
import { HEADING_KEYS, HEADING_LEVELS } from "@udecode/plate-heading";
import { HeadingPlugin } from "@udecode/plate-heading/react";
import { HighlightPlugin } from "@udecode/plate-highlight/react";
import { HorizontalRulePlugin } from "@udecode/plate-horizontal-rule/react";
import { IndentListPlugin } from "@udecode/plate-indent-list/react";
import { IndentPlugin } from "@udecode/plate-indent/react";
import { KbdPlugin } from "@udecode/plate-kbd/react";
import { LineHeightPlugin } from "@udecode/plate-line-height/react";
import { LinkPlugin } from "@udecode/plate-link/react";
import { BulletedListPlugin, ListPlugin, NumberedListPlugin, TodoListPlugin, } from "@udecode/plate-list/react";
import { ImagePlugin, MediaEmbedPlugin } from "@udecode/plate-media/react";
import { MentionInputPlugin, MentionPlugin, } from "@udecode/plate-mention/react";
import { NodeIdPlugin } from "@udecode/plate-node-id";
import { ResetNodePlugin } from "@udecode/plate-reset-node/react";
import { SelectOnBackspacePlugin } from "@udecode/plate-select";
import { BlockSelectionPlugin } from "@udecode/plate-selection/react";
import { SlashInputPlugin, SlashPlugin, } from "@udecode/plate-slash-command/react";
import { TabbablePlugin } from "@udecode/plate-tabbable/react";
import { TableCellHeaderPlugin, TableCellPlugin, TablePlugin, TableRowPlugin, } from "@udecode/plate-table/react";
import { TogglePlugin } from "@udecode/plate-toggle/react";
import { TrailingBlockPlugin } from "@udecode/plate-trailing-block";
// import { DragOverCursorPlugin } from "./components/cursor-overlay";
// COMPONENTS
import { BlockquoteElement } from "./components/blockquote-element";
import { CodeBlockElement } from "./components/code-block-element";
import { CodeLeaf } from "./components/code-leaf";
import { CodeLineElement } from "./components/code-line-element";
import { CodeSyntaxLeaf } from "./components/code-syntax-leaf";
import { CommentLeaf } from "./components/comment-leaf";
import { ExcalidrawElement } from "./components/excalidraw-element";
import { HeadingElement } from "./components/heading-element";
import { HighlightLeaf } from "./components/highlight-leaf";
import { HrElement } from "./components/hr-element";
import { ImageElement } from "./components/image-element";
import { TodoLi, TodoMarker } from "./components/indent-todo-marker-component";
import { KbdLeaf } from "./components/kbd-leaf";
import { LinkElement } from "./components/link-element";
import { LinkFloatingToolbar } from "./components/link-floating-toolbar";
import { MediaEmbedElement } from "./components/media-embed-element";
import { MentionElement } from "./components/mention-element";
import { MentionInputElement } from "./components/mention-input-element";
import { ParagraphElement } from "./components/paragraph-element";
import { withPlaceholders } from "./components/placeholder";
import { SlashInputElement } from "./components/slash-input-element";
import { TableCellElement, TableCellHeaderElement, } from "./components/table-cell-element";
import { TableElement } from "./components/table-element";
import { TableRowElement } from "./components/table-row-element";
import { TodoListElement } from "./components/todo-list-element";
// UTILS
import { withProps } from "@udecode/cn";
import { autoformatRules } from "./lib/autoformat-rules";
const usePlateEditor = ({ value = [] }) => {
    const editor = createPlateEditor({
        plugins: [
            HeadingPlugin,
            BlockquotePlugin,
            CodeBlockPlugin,
            CodeLinePlugin,
            CodeSyntaxPlugin,
            HorizontalRulePlugin,
            BasicMarksPlugin,
            TodoListPlugin,
            // Nodes
            HeadingPlugin,
            BlockquotePlugin,
            CodeBlockPlugin,
            CodeLinePlugin,
            CodeSyntaxPlugin,
            HorizontalRulePlugin,
            TogglePlugin,
            LinkPlugin.configure({
                render: { afterEditable: () => _jsx(LinkFloatingToolbar, {}) },
            }),
            ImagePlugin,
            MediaEmbedPlugin,
            CaptionPlugin.configure({
                options: { plugins: [ImagePlugin, MediaEmbedPlugin] },
            }),
            MentionPlugin,
            MentionInputPlugin,
            TablePlugin,
            TableRowPlugin,
            TableCellPlugin,
            TableCellHeaderPlugin,
            TodoListPlugin,
            ExcalidrawPlugin,
            // Marks
            BoldPlugin,
            ItalicPlugin,
            UnderlinePlugin,
            StrikethroughPlugin,
            CodePlugin,
            SubscriptPlugin,
            SuperscriptPlugin,
            FontColorPlugin,
            FontBackgroundColorPlugin,
            FontSizePlugin,
            HighlightPlugin,
            KbdPlugin,
            // Block Style
            AlignPlugin.configure({
                inject: {
                    targetPlugins: [ParagraphPlugin.key, ...HEADING_LEVELS],
                },
            }),
            IndentPlugin.configure({
                inject: {
                    targetPlugins: [
                        ParagraphPlugin.key,
                        BlockquotePlugin.key,
                        CodeBlockPlugin.key,
                        TogglePlugin.key,
                        ...HEADING_LEVELS,
                    ],
                },
            }),
            IndentListPlugin.configure({
                inject: {
                    targetPlugins: [
                        ParagraphPlugin.key,
                        BlockquotePlugin.key,
                        CodeBlockPlugin.key,
                        TogglePlugin.key,
                        ...HEADING_LEVELS,
                    ],
                },
                options: {
                    listStyleTypes: {
                        todo: {
                            liComponent: TodoLi,
                            markerComponent: TodoMarker,
                            type: "todo",
                        },
                    },
                },
            }),
            LineHeightPlugin.configure({
                inject: {
                    nodeProps: {
                        defaultNodeValue: 1.5,
                        validNodeValues: [1, 1.2, 1.5, 2, 3],
                    },
                    targetPlugins: [ParagraphPlugin.key, ...HEADING_LEVELS],
                },
            }),
            ListPlugin,
            BulletedListPlugin,
            NumberedListPlugin,
            // TABLE
            TablePlugin,
            TableRowPlugin,
            TableCellPlugin,
            TableCellHeaderPlugin,
            TabbablePlugin.configure(({ editor }) => ({
                options: {
                    query: () => {
                        if (isSelectionAtBlockStart(editor))
                            return false;
                        return !someNode(editor, {
                            match: (n) => {
                                return !!(n.type &&
                                    ([
                                        TablePlugin.key,
                                        TodoListPlugin.key,
                                        CodeBlockPlugin.key,
                                    ].includes(n.type) ||
                                        n.listStyleType));
                            },
                        });
                    },
                },
            })),
            ResetNodePlugin.configure({
                options: {
                    rules: [
                        {
                            types: [BlockquotePlugin.key, TodoListPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            hotkey: "Enter",
                            predicate: isBlockAboveEmpty,
                        },
                        {
                            types: [BlockquotePlugin.key, TodoListPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            hotkey: "Backspace",
                            predicate: isSelectionAtBlockStart,
                        },
                        {
                            types: [CodeBlockPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            onReset: unwrapCodeBlock,
                            hotkey: "Enter",
                            predicate: isCodeBlockEmpty,
                        },
                        {
                            types: [CodeBlockPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            onReset: unwrapCodeBlock,
                            hotkey: "Backspace",
                            predicate: isSelectionAtCodeBlockStart,
                        },
                    ],
                },
            }),
            // Functionality
            SlashPlugin,
            SlashInputPlugin,
            AutoformatPlugin.configure({
                options: {
                    rules: autoformatRules,
                    enableUndoOnDelete: true,
                },
            }),
            BlockSelectionPlugin,
            EmojiPlugin,
            ExitBreakPlugin.configure({
                options: {
                    rules: [
                        {
                            hotkey: "mod+enter",
                        },
                        {
                            hotkey: "mod+shift+enter",
                            before: true,
                        },
                        {
                            hotkey: "enter",
                            query: {
                                start: true,
                                end: true,
                                allow: HEADING_LEVELS,
                            },
                            relative: true,
                            level: 1,
                        },
                    ],
                },
            }),
            NodeIdPlugin,
            ResetNodePlugin.configure({
                options: {
                    rules: [
                        {
                            types: [BlockquotePlugin.key, TodoListPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            hotkey: "Enter",
                            predicate: isBlockAboveEmpty,
                        },
                        {
                            types: [BlockquotePlugin.key, TodoListPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            hotkey: "Backspace",
                            predicate: isSelectionAtBlockStart,
                        },
                        {
                            types: [CodeBlockPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            onReset: unwrapCodeBlock,
                            hotkey: "Enter",
                            predicate: isCodeBlockEmpty,
                        },
                        {
                            types: [CodeBlockPlugin.key],
                            defaultType: ParagraphPlugin.key,
                            onReset: unwrapCodeBlock,
                            hotkey: "Backspace",
                            predicate: isSelectionAtCodeBlockStart,
                        },
                    ],
                },
            }),
            SelectOnBackspacePlugin.configure({
                options: {
                    query: {
                        allow: [ImagePlugin.key, HorizontalRulePlugin.key],
                    },
                },
            }),
            SoftBreakPlugin.configure({
                options: {
                    rules: [
                        { hotkey: "shift+enter" },
                        {
                            hotkey: "enter",
                            query: {
                                allow: [
                                    CodeBlockPlugin.key,
                                    BlockquotePlugin.key,
                                    TableCellPlugin.key,
                                    TableCellHeaderPlugin.key,
                                ],
                            },
                        },
                    ],
                },
            }),
            TabbablePlugin.configure(({ editor }) => ({
                options: {
                    query: () => {
                        if (isSelectionAtBlockStart(editor))
                            return false;
                        return !someNode(editor, {
                            match: (n) => {
                                return !!(n.type &&
                                    ([
                                        TablePlugin.key,
                                        TodoListPlugin.key,
                                        CodeBlockPlugin.key,
                                    ].includes(n.type) ||
                                        n.listStyleType));
                            },
                        });
                    },
                },
            })),
            TrailingBlockPlugin.configure({
                options: { type: ParagraphPlugin.key },
            }),
            // DragOverCursorPlugin,
        ],
        override: {
            components: withPlaceholders({
                [BlockquotePlugin.key]: BlockquoteElement,
                [CodeBlockPlugin.key]: CodeBlockElement,
                [CodeLinePlugin.key]: CodeLineElement,
                [CodeSyntaxPlugin.key]: CodeSyntaxLeaf,
                [HorizontalRulePlugin.key]: HrElement,
                [HEADING_KEYS.h1]: withProps(HeadingElement, { variant: "h1" }),
                [HEADING_KEYS.h2]: withProps(HeadingElement, { variant: "h2" }),
                [HEADING_KEYS.h3]: withProps(HeadingElement, { variant: "h3" }),
                [HEADING_KEYS.h4]: withProps(HeadingElement, { variant: "h4" }),
                [HEADING_KEYS.h5]: withProps(HeadingElement, { variant: "h5" }),
                [HEADING_KEYS.h6]: withProps(HeadingElement, { variant: "h6" }),
                [ImagePlugin.key]: ImageElement,
                [LinkPlugin.key]: LinkElement,
                [MediaEmbedPlugin.key]: MediaEmbedElement,
                [MentionPlugin.key]: MentionElement,
                [MentionInputPlugin.key]: MentionInputElement,
                [ParagraphPlugin.key]: ParagraphElement,
                [TablePlugin.key]: TableElement,
                [TableRowPlugin.key]: TableRowElement,
                [TableCellPlugin.key]: TableCellElement,
                [TableCellHeaderPlugin.key]: TableCellHeaderElement,
                [TodoListPlugin.key]: TodoListElement,
                [ExcalidrawPlugin.key]: ExcalidrawElement,
                [HighlightPlugin.key]: HighlightLeaf,
                [BoldPlugin.key]: withProps(PlateLeaf, { as: "strong" }),
                [CodePlugin.key]: CodeLeaf,
                [ItalicPlugin.key]: withProps(PlateLeaf, { as: "em" }),
                [StrikethroughPlugin.key]: withProps(PlateLeaf, { as: "s" }),
                [SubscriptPlugin.key]: withProps(PlateLeaf, { as: "sub" }),
                [SuperscriptPlugin.key]: withProps(PlateLeaf, { as: "sup" }),
                [UnderlinePlugin.key]: withProps(PlateLeaf, { as: "u" }),
                [KbdPlugin.key]: KbdLeaf,
                [CommentsPlugin.key]: CommentLeaf,
                [SlashInputPlugin.key]: SlashInputElement,
                [ListPlugin.key]: withProps(PlateLeaf, { as: "ul" }),
                [BulletedListPlugin.key]: withProps(PlateLeaf, { as: "ul" }),
                [NumberedListPlugin.key]: withProps(PlateLeaf, { as: "ol" }),
            }),
        },
        value: value,
    });
    return editor;
};
export default usePlateEditor;
//# sourceMappingURL=usePlateEditor.js.map