const path = require("path");
const ESLintPlugin = require("eslint-webpack-plugin");
module.exports = {
    entry: "./src/index.ts",
    plugins: [
        new ESLintPlugin({
            context: "src",
            extensions: ["tsx", "jsx", "ts", "js"],
        }),
    ],
    devtool: "source-map",
    module: {
        rules: [
            {
                test: /\.(js|ts|jsx|tsx)$/,
                exclude: /(node_modules|bower_components)/,
                use: {
                    loader: "swc-loader",
                    options: {
                        jsc: {
                            parser: {
                                syntax: "typescript",
                            },
                        },
                    },
                },
            },
            {
                test: /\.s?[a?c]ss$/i,
                use: [
                    "style-loader",
                    "css-loader",
                    {
                        loader: "postcss-loader",
                        options: {
                            postcssOptions: {
                                plugins: [require("tailwindcss"), require("autoprefixer")],
                            },
                        },
                    },
                    "postcss-loader",
                    {
                        loader: "sass-loader",
                        options: {
                            api: "modern",
                        },
                    },
                ],
            },
        ],
    },
    resolve: {
        extensions: [".tsx", ".jsx", ".ts", ".js"],
        alias: {
            "@codemirror/state": path.resolve(__dirname, "node_modules/@codemirror/state"),
            "lodash/kebabCase": path.resolve(__dirname, "node_modules/lodash/kebabCase.js"),
        },
    },
    externals: {
        react: "react",
    },
    output: {
        library: {
            type: "umd",
        },
        globalObject: "this",
        filename: "formbuilder.js",
        path: path.resolve(__dirname, "../../service-entity/webclient/src/js/lib"), // ../../service-entity/webclient/src/js/lib
    },
    optimization: {
        removeEmptyChunks: true,
        removeAvailableModules: true,
        usedExports: true,
    },
};
//# sourceMappingURL=webpack.common.js.map